@@ -221,7 +221,8 @@ def main():
                 align_by_equal_sign=args.align_by_equal_sign,
                 flatten=args.flatten,
                 comment_max_length=args.comment_max_length,
-                new_fp=None
+                new_fp=None,
+                preview=args.preview
             )
         print_info("Done!")
 
